from django.conf.urls import url, include

from .views import AddStarReviewView, QuickCreateStarReviewView

app_name = "surveys"

reviews = ([
    url(r'^add/(?P<content_type_id>\d+)/(?P<content_id>\w+)$', AddStarReviewView.as_view(), name="reviews_add"),
    url(r'^quick-add/(?P<user_uid>\w+)/(?P<content_type_id>\d+)/(?P<uuid>[\w-]+)$',
        QuickCreateStarReviewView.as_view(), name="quick_add")
], "surveys")

urlpatterns = [
    url(r'^reviews/', include(reviews, namespace="reviews"))
]



"""
App settings inspired by Django REST Framework's

Settings are namespaced under 'DJANGO_SURVEYS' in your
project's settings.py::

    DJANGO_SURVEYS = {
        'FONT_AWESOME_CSS': None,
        'USER_HASH_FIELD': 'uuid',
        'REVIEWER_MODEL': 'users.Reviewer',
    }
"""
from django.conf import settings
from django.core.signals import setting_changed

DEFAULTS = {
    'FONT_AWESOME_CSS': '//maxcdn.bootstrapcdn.com/font-awesome/4.5.0/css/font-awesome.min.css',
    'USER_HASH_FIELD': 'username',
    'REVIEWER_MODEL': settings.AUTH_USER_MODEL,
}

SETTING_NAMESPACE = 'DJANGO_SURVEYS'


class AppSettings(object):
    def __init__(self, user_settings=None, defaults=None):
        if user_settings:
            self._user_settings = user_settings
        self.defaults = defaults or DEFAULTS

    @property
    def user_settings(self):
        if not hasattr(self, '_user_settings'):
            self._user_settings = getattr(settings, SETTING_NAMESPACE, {})
        return self._user_settings

    def __getattr__(self, attr):
        if attr not in self.defaults:
            raise AttributeError("Invalid setting: '%s'" % attr)

        try:
            # Check if present in user settings
            val = self.user_settings[attr]
        except KeyError:
            # Fall back to defaults
            val = self.defaults[attr]

        # Cache the result
        setattr(self, attr, val)
        return val


surveys_settings = AppSettings(None, DEFAULTS)


def reload_settings(*args, **kwargs):  # pylint:disable=unused-argument
    global surveys_settings
    setting, value = kwargs['setting'], kwargs['value']
    if setting == SETTING_NAMESPACE:
        surveys_settings = AppSettings(value, DEFAULTS)


setting_changed.connect(reload_settings)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('surveys', '0003_auto_20161223_1128'),
    ]

    operations = [
        migrations.RenameField(
            model_name='review',
            old_name='timestamp',
            new_name='created',
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.4 on 2016-12-21 17:20
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('surveys', '0001_squashed_0003_auto_20160803_1427'),
    ]

    operations = [
        migrations.AlterField(
            model_name='rating',
            name='value',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='ratingtype',
            name='name',
            field=models.CharField(choices=[('star-rating', 'Star')], max_length=30, unique=True),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import django.utils.timezone
from django.db import migrations, models

from surveys.settings import surveys_settings


class Migration(migrations.Migration):

    replaces = [('surveys', '0001_initial'), ('surveys', '0002_auto_20151218_1000'), ('surveys', '0003_auto_20160803_1427')]

    dependencies = [
        migrations.swappable_dependency(surveys_settings.REVIEWER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Rating',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('value', models.IntegerField(null=True)),
            ],
        ),
        migrations.CreateModel(
            name='RatingType',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(unique=True, max_length=30, choices=[('star-rating', 'Star Rating')])),
                ('min_value', models.IntegerField()),
                ('max_value', models.IntegerField()),
            ],
        ),
        migrations.CreateModel(
            name='Review',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('object_id', models.CharField(max_length=50, db_index=True)),
                ('timestamp', models.DateTimeField(default=django.utils.timezone.now)),
                ('comment', models.TextField(blank=True)),
                ('would_recommend', models.NullBooleanField(default=None)),
                ('content_type', models.ForeignKey(to='contenttypes.ContentType', on_delete=models.CASCADE)),
                ('rating', models.ForeignKey(related_name='reviews', to='surveys.Rating', on_delete=models.CASCADE)),
                ('user', models.ForeignKey(to=surveys_settings.REVIEWER_MODEL, on_delete=models.CASCADE)),
            ],
        ),
        migrations.AddField(
            model_name='rating',
            name='type',
            field=models.ForeignKey(related_name='values', to='surveys.RatingType', on_delete=models.CASCADE),
        ),
        migrations.CreateModel(
            name='StarRatedReview',
            fields=[
            ],
            options={
                'proxy': True,
            },
            bases=('surveys.review',),
        ),
        migrations.AlterUniqueTogether(
            name='review',
            unique_together=set([('object_id', 'content_type', 'user')]),
        ),
        migrations.AlterModelOptions(
            name='rating',
            options={'ordering': ['value']},
        ),
    ]



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
import sys

from setuptools import setup, find_packages

if sys.argv[-1] == 'publish':
    try:
        import wheel

        print("Wheel version: ", wheel.__version__)
    except ImportError:
        print('Wheel library missing. Please run "pip install wheel"')
        sys.exit()
    os.system('python setup.py sdist upload')
    os.system('python setup.py bdist_wheel upload')
    sys.exit()

readme = open('README.rst').read()
history = open('HISTORY.rst').read().replace('.. :changelog:', '')

setup(
    name='django-surveys',
    version='1.1.0',
    description="""A reusable Django app that lets users write feedback for any model""",
    long_description=readme + '\n\n' + history,
    author='Founders4Schools',
    author_email='dev@founders4schools.org.uk',
    url='https://github.com/founders4schools/django-surveys',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    include_package_data=True,
    install_requires=[
        "django",
        "django-model-utils",
        "djangorestframework>=3.7",
        "django-braces>=1.10.0",
    ],
    license="MIT",
    zip_safe=False,
    keywords='django-surveys',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Framework :: Django',
        'Framework :: Django :: 1.11',
        'Framework :: Django :: 2.0',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
)



from django import template

register = template.Library()


@register.inclusion_tag('surveys/survey-star-o.svg')
def star_svg(width=50, color=None):
    return {
        'width': width,
        'color': color,
    }


@register.inclusion_tag('surveys/5-stars.html')
def five_stars_html(object_rate_url):
    """Helper to include rating links in a HTML email"""
    return {
        'object_rate_url': object_rate_url,
    }


@register.inclusion_tag('surveys/5-stars.txt')
def five_stars_text(object_rate_url, cta="Click here for a rating of"):
    """Helper to include rating links in a text email"""
    return {
        'cta': cta,
        'object_rate_url': object_rate_url,
    }
